window.Gleam.initSearch([{"doc":"snowgleam","title":"snowgleam","content":"# Snowgleam ❄️\n\n[![Package Version](https://img.shields.io/hexpm/v/snowgleam)](https://hex.pm/packages/snowgleam)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/snowgleam/)\n\nGleam version of the Twitter&#39;s [snowflake](https://github.com/twitter-archive/snowflake/tree/snowflake-2010) format for unique IDs.\nAlthough it is more inspired by the Discord [implementation](https://discord.com/developers/docs/reference#snowflakes) of the snowflake format.\n\nThey are great for generating unique IDs in a distributed system.\n\n```sh\ngleam add snowgleam\n```\nAnd then use it in your project like this:\n```gleam\nimport gleam/io\nimport gleam/int\nimport snowgleam\n\npub fn main() {\n  let assert Ok(generator) = snowgleam.new_generator() |&gt; snowgleam.start()\n  let id = generator |&gt; snowgleam.generate()\n  io.println(&quot;Generated ID: &quot; &lt;&gt; id |&gt; int.to_string())\n}\n```\n\n## Features\n- Setup with a custom epoch\n- Simple ID generation\n- Lazy ID generation\n- Lazy ID generation with custom timestamp (useful for backfilling)\n\nFurther documentation can be found at &lt;https://hexdocs.pm/snowgleam&gt;.\n","url":"index.html"},{"doc":"snowgleam","title":"Generator","content":"pub type Generator =\n  process.Subject(Message)\n Type alias for the genarator message subject. It is the actual\n public interface for the generator and should be used to interact with it.\n\n # Examples\n \n import gleam/snowgleam\n\n pub type Context {\n   Context(generator: snowgleam.Generator)\n }\n\n let assert Ok(generator) = snowgleam.new_generator() |&gt; snowgleam.start()\n let context = Context(generator: generator)\n let id = context.generator |&gt; snowgleam.generate()\n \n\nSynonyms:\nsnowgleam.Generator\nsnowgleam Generator","url":"snowgleam.html#Generator"},{"doc":"snowgleam","title":"Message","content":"pub opaque type Message\n The messages that the generator can receive.\n\nSynonyms:\nsnowgleam.Message\nsnowgleam Message","url":"snowgleam.html#Message"},{"doc":"snowgleam","title":"Node","content":"pub opaque type Node\n The Snowflake ID generator node.\n A node holds the state of the generator and is used to generate IDs.\n\nSynonyms:\nsnowgleam.Node\nsnowgleam Node","url":"snowgleam.html#Node"},{"doc":"snowgleam","title":"default_epoch","content":"pub const default_epoch: Int\n The default epoch for the generator. Corresponds to the Twitter epoch.\nSynonyms:\nsnowgleam.default_epoch\nsnowgleam default_epoch","url":"snowgleam.html#default_epoch"},{"doc":"snowgleam","title":"generate","content":"pub fn generate(node: Subject(Message)) -&gt; Int\n Generates a new Snowflake ID.\n\n # Examples\n \n import gleam/snowgleam\n\n let epoch = 1_420_070_400_000\n let worker_id = 12\n let process_id = 1\n\n let assert Ok(generator) =\n   snowgleam.new_generator()\n   |&gt; snowgleam.with_epoch(epoch)\n   |&gt; snowgleam.with_worker_id(worker_id)\n   |&gt; snowgleam.with_process_id(process_id)\n   |&gt; snowgleam.start()\n\n let id = snowgleam.generate(generator)\n \nSynonyms:\nsnowgleam.generate\nsnowgleam generate","url":"snowgleam.html#generate"},{"doc":"snowgleam","title":"generate_lazy","content":"pub fn generate_lazy(node: Subject(Message)) -&gt; Int\n Generates a new Snowflake ID lazily.\n It works like the `generate` function but it does not uses the current\n timestamp, instead it consumes all the 4096 IDs of every millisecond.\n It may be faster and useful in some cases than the `generate` function.\n For example, to generate a batch of IDs or to generate IDs for a particular\n time.\nSynonyms:\nsnowgleam.generate_lazy\nsnowgleam generate_lazy","url":"snowgleam.html#generate_lazy"},{"doc":"snowgleam","title":"new_generator","content":"pub fn new_generator() -&gt; Node\n Creates a new Snowflake ID generator with default settings.\nSynonyms:\nsnowgleam.new_generator\nsnowgleam new_generator","url":"snowgleam.html#new_generator"},{"doc":"snowgleam","title":"process_id","content":"pub fn process_id(id: Int) -&gt; Int\n Extracts the process ID from a Snowflake ID.\nSynonyms:\nsnowgleam.process_id\nsnowgleam process_id","url":"snowgleam.html#process_id"},{"doc":"snowgleam","title":"start","content":"pub fn start(node: Node) -&gt; Result(Subject(Message), String)\n Starts the generator.\nSynonyms:\nsnowgleam.start\nsnowgleam start","url":"snowgleam.html#start"},{"doc":"snowgleam","title":"timestamp","content":"pub fn timestamp(id: Int, epoch: Int) -&gt; Int\n Extracts the timestamp from a Snowflake ID using the provided epoch.\nSynonyms:\nsnowgleam.timestamp\nsnowgleam timestamp","url":"snowgleam.html#timestamp"},{"doc":"snowgleam","title":"with_epoch","content":"pub fn with_epoch(node: Node, epoch: Int) -&gt; Node\n Sets the epoch for the generator.\nSynonyms:\nsnowgleam.with_epoch\nsnowgleam with_epoch","url":"snowgleam.html#with_epoch"},{"doc":"snowgleam","title":"with_process_id","content":"pub fn with_process_id(node: Node, process_id: Int) -&gt; Node\n Sets the process ID for the generator.\nSynonyms:\nsnowgleam.with_process_id\nsnowgleam with_process_id","url":"snowgleam.html#with_process_id"},{"doc":"snowgleam","title":"with_timestamp","content":"pub fn with_timestamp(node: Node, last_ts: Int) -&gt; Node\n Sets timestamp for the generator. Useful for lazy generation. It should not\n be used along with normal generation.\nSynonyms:\nsnowgleam.with_timestamp\nsnowgleam with_timestamp","url":"snowgleam.html#with_timestamp"},{"doc":"snowgleam","title":"with_worker_id","content":"pub fn with_worker_id(node: Node, worker_id: Int) -&gt; Node\n Sets the worker ID for the generator.\nSynonyms:\nsnowgleam.with_worker_id\nsnowgleam with_worker_id","url":"snowgleam.html#with_worker_id"},{"doc":"snowgleam","title":"worker_id","content":"pub fn worker_id(id: Int) -&gt; Int\n Extracts the worker ID from a Snowflake ID.\nSynonyms:\nsnowgleam.worker_id\nsnowgleam worker_id","url":"snowgleam.html#worker_id"},{"doc":"snowgleam","title":"snowgleam","content":" A module for generating unique IDs using the Twitter Snowflake algorithm.","url":"snowgleam.html"}]);